@@ -1,3 +1,8 @@
+'''
+The Estimators module contains a variety of statistical estimators that can be applied to multivariate datasets.
+'''
+
+
 # TODO: Consider suggestions at https://stackoverflow.com/questions/35673895/type-hinting-annotation-pep-484-for-numpy-ndarray
 # TODO: Ensure code follows style guide: https://numpydoc.readthedocs.io/en/latest/format.html
 from numba import jit
@@ -5,6 +10,69 @@ import numpy as np
 from scipy.stats import rankdata
 import tqdm
 
+
+def kendall_tau(X: np.ndarray, method='A') -> np.float64:
+    '''
+    Multivariate Kendall's tau.
+
+    Parameters
+    ----------
+    X : array-like
+        An m x n data matrix.
+    method : {'A', 'B', 'C'}, optional
+            The method used to account for tied points.
+            The following methods are available (default is 'a'):
+          * 'A': Original Kendall's Tau.
+          * 'B': :math:`\\tau_B = \\frac{m_c - m_d}{\\sqrt[n]{\\prod_{j=1}^{n} (m_0 - m_j)}}`
+          * 'C': :math:`\tau_C = \\frac{2 (m_c - m_d) }{m^2 \\frac{(\\max(m,n) - 1)}{\\max(m,n)}}`
+
+    Returns
+    -------
+     : np.float64
+        Multivariate Kendall's tau score
+
+    Raises
+    ------
+    NotImplementedError : Method B is not implemented yet.
+
+    References
+    ----------
+    .. [1] "Kendall's Tau.", https://en.wikipedia.org/wiki/Kendall_rank_correlation_coefficient
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> estimators.kendall_tau(data)
+    1.0
+    '''
+
+    concordant = 0
+    discordant = 0
+
+    for i, xi in enumerate(X):
+        for j, xj in enumerate(X):
+            if i < j:
+                if (np.all(xi < xj) or np.all(xi > xj)):
+                    concordant += 1
+                else:
+                    discordant += 1
+            else:
+                continue
+    if method == 'A':
+        return (concordant - discordant) / ((X.shape[0] **2 - X.shape[0]) / 2)
+    elif method == 'B':
+        raise NotImplementedError ('Method B is not implemented yet.')
+    elif method == 'C':
+        m = np.min(X.shape)
+        result =  2 * (concordant - discordant)
+        result /= X.shape[0]**2
+        result /= (m-1) / m
+        return result
+
+
+
+
 def grade_entropy(X: np.ndarray) -> np.float64:
     '''
     Computes grade entropy for a strict product order
@@ -241,7 +309,7 @@ def spearman_correlation(X: np.ndarray, method='average') -> np.float64:
     This function estimates
 
     .. math::
-        R_c \\left[ X_1, \\cdots, X_n \\right] = \\frac{\\mathbb{E} \\left[ \\prod_{j=1}^{n} \\text{rank} \\left( X_j - \\mathbb{E}[X_j] \\right) \\right]}{\\prod_{j=1}^{n} \\sqrt[n]{\\mathbb{E}\\left[ |\\text{rank} \\left( X_j - \\mathbb{E}[X_j] \\right)|^n \\right]}}
+        R_c \\left[ X_1, \\cdots, X_n \\right] = \\frac{\\mathbb{E} \\left[ \\prod_{j=1}^{n} \\text{rank} \\left( X_j \\right) - \\mathbb{E}[\\text{rank} \\left( X_j \\right)] \\right]}{\\prod_{j=1}^{n} \\sqrt[n]{\\mathbb{E}\\left[ |\\text{rank} \\left( X_j \\right) - \\mathbb{E}[\\text{rank} \\left( X_j \\right)]|^n \\right]}}
     
     Parameters
     ----------
@@ -524,6 +592,7 @@ def taylor_correlation(X: np.ndarray) -> np.float64:
         m x n data matrix
 
     Returns
+    -------
     : np.float64
         Taylor correlation score
 
@@ -566,7 +635,7 @@ def trencevski_malceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
 
     Returns
     ----------
-        : float
+        : np.float64
             Correlation score.
 
     References
