@@ -80,9 +80,8 @@ def minkowski_deviation(f, I, p=2, *args, **kwargs):
         to the variables in f.
 
     .. warning::
-        A sufficiently large input value for `p` can
-        result numerical issues such as numerical
-        underflow. See `Arithmetic underflow <https://en.wikipedia.org/wiki/Arithmetic_underflow>`_.
+        A sufficiently large input value for p can
+        result numerical issues such as `arithmetic underflow underflow <https://en.wikipedia.org/wiki/Arithmetic_underflow>`_.
     '''
     lower = np.array(I)[:,0]
     upper = np.array(I)[:,1]
@@ -106,8 +105,8 @@ def covariance(F, I, *args, **kwargs):
 
     Parameters
     ----------
-    f: function.
-        Function to be integrated.
+    F: array-like[function].
+        Functions to be integrated.
     I: array-like
         Integration bounds.
 
@@ -150,8 +149,8 @@ def pearson_correlation(F, I, *args, **kwargs):
 
     Parameters
     ----------
-    f: function.
-        Function to be integrated.
+    F: array-like[function].
+        Functions to be integrated.
     I: array-like
         Integration bounds.
 
